@@ -217,6 +217,7 @@ public:
         std::atomic<bool> ip_nat = { false };
         std::atomic<bool> soft_dissector = { false };
         std::atomic<bool> app_ip_override = { false };
+        std::atomic<bool> app_proto_twins = { false };
     } flags;
 
     struct {
@@ -267,12 +268,12 @@ public:
     std::string detected_application_name;
 
     struct {
-        nd_cat_id_t application = { ND_CAT_UNKNOWN };
-        nd_cat_id_t protocol = { ND_CAT_UNKNOWN };
-        nd_cat_id_t domain = { ND_CAT_UNKNOWN };
-        nd_cat_id_t upper_net = { ND_CAT_UNKNOWN };
-        nd_cat_id_t lower_net = { ND_CAT_UNKNOWN };
-        nd_cat_id_t overlay = { ND_CAT_UNKNOWN };
+        ndCategories::Id application = { ndCategory::UNKNOWN };
+        ndCategories::Id protocol = { ndCategory::UNKNOWN };
+        ndCategories::Id domain = { ndCategory::UNKNOWN };
+        ndCategories::Id upper_net = { ndCategory::UNKNOWN };
+        ndCategories::Id lower_net = { ndCategory::UNKNOWN };
+        ndCategories::Id overlay = { ndCategory::UNKNOWN };
     } category;
 
     struct {
@@ -522,6 +523,8 @@ public:
               (bool)flags.soft_dissector.load());
             serialize(output, { "app_ip_override" },
               (bool)flags.app_ip_override.load());
+            serialize(output, { "app_proto_twins" },
+              (bool)flags.app_proto_twins.load());
             serialize(output, { "ip_version" }, (unsigned)ip_version);
             serialize(output, { "ip_dscp" }, (unsigned)ip_dscp);
             serialize(output, { "ip_protocol" },
